# live_indonesia_earthquake
This package gets the latest earthquake in Indonesia from the official government agency

## How does it work?
This package scrapes live Indonesian earthquake data from Indonesian Agency for Meteorological, Climatological and Geophysics ([BMKG](https://bmkg.go.id)).
It uses BeautifulSoup4 and Requests packages to produce outputs in the form of JSON. The generated outputs is readily available for web or mobile applications.

